@@ -2,7 +2,7 @@
 # -*- coding: utf8 -*-
 
 import re, platform, os, pwd
-from puke.Tools import *
+from puke.ToolsExec import *
 from distutils import version
 
 
