@@ -2,8 +2,6 @@
 # -*- coding: utf8 -*-
 
 import os, os.path, shutil, logging, sys, filecmp, stat, re, time
-import shlex, subprocess
-
 
 
 from puke.FileList import *
@@ -11,18 +9,14 @@ from puke.Console import *
 from scss import Scss
 from puke.FileSystem import *
 from puke.Compress import *
+from puke.Std import *
+from puke.ToolsExec import *
+
 
 
 from puke.Cache import *
+import System
 
-import signal
-
-
-class Alarm(Exception):
-    pass
-
-def alarm_handler(signum, frame):
-    raise Alarm
 
 
 
@@ -76,6 +70,8 @@ def combine(in_files, out_file, verbose=False, replace = None):
 
 def minify(in_file, out_file = None, verbose=False):
 
+    System.check_package('java')
+
     if not isinstance(in_file, str):
         raise Exception("Minify : single file only")
 
@@ -109,6 +105,8 @@ def minify(in_file, out_file = None, verbose=False):
 
 
 def jslint(files, fix = False, relax = False, fail = True):
+    System.check_package('java')
+
     files = FileList.check(files)
 
     options = []
@@ -138,6 +136,8 @@ def jslint(files, fix = False, relax = False, fail = True):
 
 
 def jsdoc(files, folder, template = None, fail = True):
+    System.check_package('java')
+
     files = FileList.check(files)
 
     if not template:
@@ -173,52 +173,6 @@ def patch(dir, patch):
         
 
 
-def sh (command, header = None, output = True, timeout = None):
-    if isinstance(command, list):
-        command = " ; ".join(command)
-
-
-    if header == None:
-        header = 'exec "%s" ' % command
-    else:
-        console.debug(command)
-    
-    if output and header != False:
-        console.header(' - '+header)
-    
-    result = ""
-    args = shlex.split(command)
-
-    if timeout:
-        signal.signal(signal.SIGALRM, alarm_handler)
-        signal.alarm(timeout)  # 5 seconds
-
-    try:
-        cProcess = subprocess.Popen(command, stdout = subprocess.PIPE, shell = True, stderr= subprocess.PIPE, executable='/bin/bash', env=os.environ)
-        (stdout, error) = cProcess.communicate()
-        signal.alarm(0)
-    except Alarm:
-        console.warn('taking too long (%s)' % command)
-        cProcess.kill()
-        stdout = error = ""
-   
-    stdout = "%s\n%s" % (stdout if stdout else '', error if error else '')
-
-    lines = stdout.split('\n')
-    for line in lines:
-        if not line:
-            continue
-
-        result += line
-        
-        if not line.endswith('\n'):
-            result += '\n'
-
-        if output == True:
-            console.info( '   ' +line)
-   
-    return result
-
 def prompt(message, default = ''):
     console.warn(message)
     result = sh('read toto && echo $toto', header = None, output=False)
@@ -387,6 +341,9 @@ def unpack (pack_file, output):
 
 ### WIP
 def __jasmine(files):
+
+    System.check_package('java')
+
     files = [files]
 
     envjs =  os.path.join(__get_datas_path(), 'envjs')
